@@ -13,7 +13,7 @@ from datetime import datetime
 import statistics
 from botocore.exceptions import ClientError
 import numbers
-from matplotlib.colors import LogNorm
+from matplotlib.colors import LogNorm, Normalize
 
 
 def days_diff(d1, d2):
@@ -705,7 +705,7 @@ def plot_node(
     print("Creating Heatmap of Differences of Releases")
     image_name = 'data_diff_heatmap.png'
     plt.figure(figsize=(12, 12))
-    plt.pcolormesh(data_df.diff(axis=1), norm=LogNorm(vmin=1))
+    plt.pcolormesh(data_df.diff(axis=1), norm=Normalize())
     len_ind = len(data_df.index)
     len_cols = len(data_df.columns)
     ynum = max(len_ind // 10, 1)
